@@ -461,7 +461,7 @@ register_keys_plugin (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
-                 _("Plugin '%s' is already loaded"), grl_plugin_get_id (plugin));
+                 _("Plugin “%s” is already loaded"), grl_plugin_get_id (plugin));
     return FALSE;
   }
 
@@ -527,7 +527,7 @@ grl_registry_register_metadata_key_full (GrlRegistry *registry,
       g_set_error (error,
                    GRL_CORE_ERROR,
                    GRL_CORE_ERROR_REGISTER_METADATA_KEY_FAILED,
-                   _("Metadata key '%s' already registered in different format"),
+                   _("Metadata key “%s” already registered in different format"),
                    key_name);
       return GRL_METADATA_KEY_INVALID;
     }
@@ -540,7 +540,7 @@ grl_registry_register_metadata_key_full (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_REGISTER_METADATA_KEY_FAILED,
-                 _("Metadata key '%s' cannot be registered"),
+                 _("Metadata key “%s” cannot be registered"),
                  key_name);
 
     return GRL_METADATA_KEY_INVALID;
@@ -980,7 +980,7 @@ grl_registry_unregister_source (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_UNREGISTER_SOURCE_FAILED,
-                 _("Source with id '%s' was not found"), id);
+                 _("Source with id “%s” was not found"), id);
     ret = FALSE;
   }
 
@@ -1074,7 +1074,7 @@ grl_registry_prepare_plugin (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
-                 _("'%s' is not a valid plugin file"), library_filename);
+                 _("“%s” is not a valid plugin file"), library_filename);
     g_module_close (module);
     return NULL;
   }
@@ -1093,7 +1093,7 @@ grl_registry_prepare_plugin (GrlRegistry *registry,
       g_set_error (error,
                    GRL_CORE_ERROR,
                    GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
-                   _("Plugin '%s' already exists"), library_filename);
+                   _("Plugin “%s” already exists"), library_filename);
       return NULL;
     }
   }
@@ -1363,7 +1363,7 @@ grl_registry_activate_plugin_by_id (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
-                 _("Plugin '%s' not available"), plugin_id);
+                 _("Plugin “%s” not available"), plugin_id);
     return FALSE;
   }
 
@@ -1374,7 +1374,7 @@ grl_registry_activate_plugin_by_id (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
-                 _("Plugin '%s' is already loaded"), plugin_id);
+                 _("Plugin “%s” is already loaded"), plugin_id);
     return FALSE;
   }
 
@@ -1591,7 +1591,7 @@ grl_registry_unload_plugin (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_UNLOAD_PLUGIN_FAILED,
-                 _("Plugin not found: '%s'"), plugin_id);
+                 _("Plugin not found: “%s”"), plugin_id);
     return FALSE;
   }
 
@@ -1902,7 +1902,7 @@ grl_registry_add_config (GrlRegistry *registry,
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_CONFIG_FAILED,
-                 _("Plugin configuration does not contain 'plugin-id' reference"));
+                 _("Plugin configuration does not contain “plugin-id” reference"));
     return FALSE;
   }
 
